package com.qmth.teachcloud.mark.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qmth.teachcloud.common.contant.SystemConstant;
import com.qmth.teachcloud.mark.dto.mark.manage.TaskQuestion;
import com.qmth.teachcloud.mark.entity.MarkArchiveStudent;
import com.qmth.teachcloud.mark.mapper.MarkArchiveStudentMapper;
import com.qmth.teachcloud.mark.service.MarkArchiveStudentService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 考生归档数据表 服务实现类
 * </p>
 *
 * @author xf
 * @since 2025-03-21
 */
@Service
public class MarkArchiveStudentServiceImpl extends ServiceImpl<MarkArchiveStudentMapper, MarkArchiveStudent> implements MarkArchiveStudentService {

    @Override
    public List<MarkArchiveStudent> listByStudentIds(List<Long> studentIds) {
        QueryWrapper<MarkArchiveStudent> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().in(MarkArchiveStudent::getStudentId, studentIds);
        return this.list(queryWrapper);
    }

    @Override
    public List<TaskQuestion> listTaskQuestionByStudentIds(List<Long> studentIds) {
        List<MarkArchiveStudent> markArchiveStudents = this.listByStudentIds(studentIds);
        List<TaskQuestion> taskQuestions = markArchiveStudents.stream()
                .filter(m -> StringUtils.isNotBlank(m.getSubjectiveQuestions()))
                .map(m -> JSON.parseArray(m.getSubjectiveQuestions(), TaskQuestion.class))
                .flatMap(List::stream).collect(Collectors.toList());
        return taskQuestions;
    }
}
